import * as i0 from '@angular/core';
import { Component, Input, NgModule } from '@angular/core';
import { fadeInOnEnterAnimation, fadeOutOnLeaveAnimation } from 'angular-animations';
import { asyncScheduler } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'ngx-highlightjs';
import { HighlightModule, HIGHLIGHT_OPTIONS } from 'ngx-highlightjs';

class CodeSnippetComponent {
    constructor() {
        /** Code snippet to display */
        this.code = '';
        /** Format of the code */
        this.language = '';
        /** Whether copy button has been pressed */
        this.copied = false;
        /** Length of time in which copied text appears (ms) */
        this.copiedTextLength = 2000;
    }
    /**
     * On destroy lifecycle hook
     */
    ngOnDestroy() {
        this.copyTextSub?.unsubscribe();
    }
    /**
     * Copies code to the clipboard
     */
    copyToClipboard() {
        navigator.clipboard.writeText(this.code);
        this.copied = true;
        this.copyTextSub = asyncScheduler.schedule(() => (this.copied = false), this.copiedTextLength);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.7", type: CodeSnippetComponent, selector: "code-snippet", inputs: { code: "code", language: "language" }, ngImport: i0, template: "<!-- Code -->\n<pre><code class=\"code-container\" [highlight]=\"code\" [languages]=\"[language]\"></code></pre>\n\n<!-- Copy to Clipboard -->\n<div class=\"clipboard-container\">\n    <span *ngIf=\"copied\" class=\"copied-text\" [@fadeInOnEnter] [@fadeOutOnLeave]>Copied!</span>\n    <button class=\"copy-button\" title=\"Copy to clipboard.\" (click)=\"copyToClipboard()\">\n        <i class=\"eva\" [class]=\"copied ? 'eva-checkmark-outline' : 'eva-copy-outline'\"></i>\n    </button>\n</div>\n", styles: [":host{position:relative;width:100%}.code-container{border-radius:8px}.clipboard-container{position:absolute;top:.5em;right:.5em;z-index:1;display:flex}.copied-text{display:flex;align-items:center;font-size:.85rem;color:#fff;background-color:#0d1117;padding:0 5px;margin:0 5px}.copy-button{min-width:30px;display:flex;align-items:center;justify-content:center;color:#fff;padding:5px;font-size:1.125rem;border:1px solid rgba(255,255,255,.1333333333);border-radius:.25rem;outline:none;background-color:#3a394d}.copy-button:hover{cursor:pointer}.copy-button:focus-visible{outline:-webkit-focus-ring-color auto 1px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.Highlight, selector: "[highlight]", inputs: ["highlight", "languages", "lineNumbers"], outputs: ["highlighted"] }], animations: [fadeInOnEnterAnimation(), fadeOutOnLeaveAnimation()] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'code-snippet', animations: [fadeInOnEnterAnimation(), fadeOutOnLeaveAnimation()], template: "<!-- Code -->\n<pre><code class=\"code-container\" [highlight]=\"code\" [languages]=\"[language]\"></code></pre>\n\n<!-- Copy to Clipboard -->\n<div class=\"clipboard-container\">\n    <span *ngIf=\"copied\" class=\"copied-text\" [@fadeInOnEnter] [@fadeOutOnLeave]>Copied!</span>\n    <button class=\"copy-button\" title=\"Copy to clipboard.\" (click)=\"copyToClipboard()\">\n        <i class=\"eva\" [class]=\"copied ? 'eva-checkmark-outline' : 'eva-copy-outline'\"></i>\n    </button>\n</div>\n", styles: [":host{position:relative;width:100%}.code-container{border-radius:8px}.clipboard-container{position:absolute;top:.5em;right:.5em;z-index:1;display:flex}.copied-text{display:flex;align-items:center;font-size:.85rem;color:#fff;background-color:#0d1117;padding:0 5px;margin:0 5px}.copy-button{min-width:30px;display:flex;align-items:center;justify-content:center;color:#fff;padding:5px;font-size:1.125rem;border:1px solid rgba(255,255,255,.1333333333);border-radius:.25rem;outline:none;background-color:#3a394d}.copy-button:hover{cursor:pointer}.copy-button:focus-visible{outline:-webkit-focus-ring-color auto 1px}\n"] }]
        }], ctorParameters: () => [], propDecorators: { code: [{
                type: Input
            }], language: [{
                type: Input
            }] } });

class CodeSnippetModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetModule, declarations: [CodeSnippetComponent], imports: [CommonModule, HighlightModule], exports: [CodeSnippetComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetModule, providers: [
            {
                provide: HIGHLIGHT_OPTIONS,
                useValue: {
                    fullLibraryLoader: () => import('highlight.js'),
                },
            },
        ], imports: [CommonModule, HighlightModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.7", ngImport: i0, type: CodeSnippetModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CodeSnippetComponent],
                    imports: [CommonModule, HighlightModule],
                    exports: [CodeSnippetComponent],
                    providers: [
                        {
                            provide: HIGHLIGHT_OPTIONS,
                            useValue: {
                                fullLibraryLoader: () => import('highlight.js'),
                            },
                        },
                    ],
                }]
        }] });

/*
 * Public API Surface of ngx-code-snippet
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CodeSnippetComponent, CodeSnippetModule };
//# sourceMappingURL=ngx-code-snippet.mjs.map
